# © Copyright [2018 - 2020, 2022] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

#This file updates iptable whenever
# 1) cis service start
# 2) suse firewall stops
# 3) suse firewall starts

iptables=/usr/sbin/iptables
firewallcmd=/usr/bin/firewall-cmd
OPTION=$1
networkip=$(docker network inspect -f "{{(index (.IPAM.Config) 0).Subnet}}" cisnet) 2>/dev/null
if [[ $? != 0  ||  $networkip == "" ]] ; then
        echo "cisnet not found. Opening Bridge network for CIS Data scale"
        networkip=$(docker network inspect -f "{{(index (.IPAM.Config) 0).Subnet}}" bridge) 2>/dev/null
        if [[ $? != 0  ||  $networkip == "" ]] ; then
                echo "Bridge network not found"
                exit 0
        fi
fi

# Relaoding firewalld to get the iptable udpated with latest entry before doing iptable search
if ! $firewallcmd --reload; then
        echo "oes-cis: Failed to relaod firewalld"
fi

if ! $iptables -C FORWARD -s $networkip -j ACCEPT 2>/dev/null; then
        case $OPTION in
                "on-firewall-stop")
                        # Adding firewall rules with iptables command when firewall is not running
                        if ! $iptables -I FORWARD -s $networkip -j ACCEPT 2>/dev/null; then
                                echo "oes-cis: Failed to update docker to other network rule in FORWARD chain"
                        fi
                        if ! $iptables -I FORWARD -d $networkip -j ACCEPT 2>/dev/null; then
                                echo "oes-cis: Failed to update other network to docker rule in FORWARD chain"
                        fi
                        sysctl -w net.ipv4.ip_forward=1
                        if ! $iptables -t nat -I POSTROUTING -s $networkip -j MASQUERADE; then
                                echo "oes-cis: Failed to update rule in POSTROUTING chain"
                        fi
                        ;;
                *)
                        # Adding firewalld direct rules while starting firewalld or update-iptables service
                        if ! $firewallcmd  --permanent --direct --add-rule ipv4 filter FORWARD 0  -s $networkip -j ACCEPT 2>/dev/null; then
                                echo "oes-cis: Failed to update docker to other network rule in FORWARD chain"
                        fi
                        if ! $firewallcmd  --permanent --direct --add-rule ipv4 filter FORWARD 0  -d $networkip -j ACCEPT 2>/dev/null; then
                                echo "oes-cis: Failed to update other network to docker rule in FORWARD chain"
                        fi
                        sysctl -w net.ipv4.ip_forward=1
                        if ! firewall-cmd --permanent --direct --add-rule ipv4 nat POSTROUTING 0 -s $networkip -j MASQUERADE 2>/dev/null; then
                                echo "oes-cis: Failed to update rule in POSTROUTING chain"
                        fi
                        if ! $firewallcmd --reload; then
                                echo "oes-cis: Failed to relaod firewalld"
                        fi
                        ;;
        esac
fi

exit 0
